package drakvirt;

use common;

sub get_icon() { 'drakvirt' }

sub install_guest {
    my ($in, $virtual) = @_;
    require wizards;
    my $already_in_wizard = defined $::WizardWindow;
    my $guest_domain_settings;
    my $guest_filesystem_settings;
    my $wiz = wizards->new({
        defaultimage => get_icon(),
        name => N("Guest installation"),
        pages => {
            welcome => {
                if_(!$::isInstall, no_back => 1),
                name => N("This wizard will help you to install a guest domain."),
                next => "domain",
            },
            domain => {
                name => N("Please enter the settings of your guest domain"),
                pre => sub { $guest_domain_settings = $virtual->get_guest_domain_settings },
                data => sub { $guest_domain_settings },
                complete => sub {
                    if (!$virtual->check_guest_domain_settings) {
                        $in->ask_warn(N("Error"), $virtual->{guest}{error}{message});
                        my $index = eval { find_index { $_->{val} eq $virtual->{guest}{error}{field} } @$guest_domain_settings };
                        return 1, $index;
                    }
                    return 0;
                },
                next => "filesystem",
            },
            filesystem => {
                name => N("Please enter the settings of your guest filesystem"),
                pre => sub { $guest_filesystem_settings = $virtual->get_guest_filesystem_settings },
                data => sub { $guest_filesystem_settings },
                complete => sub {
                    if (!$virtual->check_guest_filesystem_settings) {
                        $in->ask_warn(N("Error"), $virtual->{guest}{error}{message});
                        my $index = eval { find_index { $_->{val} eq $virtual->{guest}{error}{field} } @$guest_filesystem_settings };
                        return 1, $index;
                    }
                    return 0;
                },
                end => 1,
            },
        },
    });
    eval { $wiz->process($in) };
    my $err = $@;
    if (!$already_in_wizard) {
        $::WizardWindow->destroy if $::WizardWindow;
        $::WizardTable->destroy if $::WizardTable;
        undef $::WizardTable;
        undef $::WizardWindow;
    }
    return if $err =~ /wizcancel/;
    die $err if $err;

    eval { $virtual->install_guest($in) };
    $err = $@;
    $in->ask_warn(N("Error"), N("An unexpected error has happened:\n%s", $err)) if $err;
}

1;
